summaryrefslogtreecommitdiffstats
path: root/korn/boxcontaineritem.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/boxcontaineritem.h')
-rw-r--r--korn/boxcontaineritem.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/korn/boxcontaineritem.h b/korn/boxcontaineritem.h
index 46f85da5..0112f9ac 100644
--- a/korn/boxcontaineritem.h
+++ b/korn/boxcontaineritem.h
@@ -46,14 +46,14 @@ class BoxContainerItem : public AccountManager, public DCOPObject
public:
/**
* Standaard QObject-constuctor
* This constructor implements the default arguments for any QObject.
* Note that is does not give a name to DCOPObject; that name
* is set in the readConfig-function.
* @param parent The parent of this object, See Object::QObject
* @param name The name of this object, See QObject::QObject
* @see BoxContainerItem::readConfig
*/
- BoxContainerItem( QObject * parent = 0, const char * name = 0 );
+ BoxContainerItem( TQObject * parent = 0, const char * name = 0 );
/**
* The default destructor. This only removes _command-pointer.
@@ -86,7 +86,7 @@ public slots:
*
* @param cmd The command to be executed.
*/
- virtual void runCommand( const QString& cmd );
+ virtual void runCommand( const TQString& cmd );
/**
* This function displays the (kde) help dialog
@@ -128,7 +128,7 @@ protected:
* @param accountName The name of the account it belongs to
* @param date Should the date be displayed?
*/
- void showPassivePopup( QWidget* parent, QPtrList< KornMailSubject >* list, int total, const QString& accountName, bool date );
+ void showPassivePopup( TQWidget* parent, TQPtrList< KornMailSubject >* list, int total, const TQString& accountName, bool date );
//this functions should be reimplemented
/**
@@ -143,7 +143,7 @@ protected:
* @param count the number of new messages
* @param newMessages are the messages new?
*/
- void drawLabel( QLabel *label, const int count, const bool newMessages );
+ void drawLabel( TQLabel *label, const int count, const bool newMessages );
private:
/**
@@ -153,14 +153,14 @@ private:
* @param font the font; 0 is default font.
* @param count the number of messages
*/
- static QPixmap calcComplexPixmap( const QPixmap &icon, const QColor& fgColour, const QFont* font, const int count );
+ static TQPixmap calcComplexPixmap( const TQPixmap &icon, const TQColor& fgColour, const TQFont* font, const int count );
/**
* This functions sets a movie to a specified label
* @param label The label to set the movie in
* @param anim The path to the animation
*/
- void setAnimIcon( QLabel* label, const QString& anim );
+ void setAnimIcon( TQLabel* label, const TQString& anim );
private slots:
void slotRecheck() { recheck(); }
@@ -218,14 +218,14 @@ private slots:
protected:
//This settings are stored here because every implementation needs them.
- QString *_icons[ 2 ];
- QString *_anims[ 2 ];
- QColor *_fgColour[ 2 ];
- QColor *_bgColour[ 2 ];
- QFont *_fonts[ 2 ];
+ TQString *_icons[ 2 ];
+ TQString *_anims[ 2 ];
+ TQColor *_fgColour[ 2 ];
+ TQColor *_bgColour[ 2 ];
+ TQFont *_fonts[ 2 ];
private:
- QString *_command;
+ TQString *_command;
bool _recheckSettings[ 3 ];
bool _resetSettings[ 3 ];
bool _viewSettings[ 3 ];
@@ -46,14 +46,14 @@ class BoxContainerItem : public AccountManager, public DCOPObject
/**
* Standaard QObject-constuctor
- * This constructor implements the default arguments for any QObject.
+ * This constructor implements the default arguments for any TQObject.
* Note that is does not give a name to DCOPObject; that name
* is set in the readConfig-function.
@@ -46,14 +46,14 @@ class BoxContainerItem : public AccountManager, public DCOPObject
* is set in the readConfig-function.
* @param parent The parent of this object, See Object::QObject
- * @param name The name of this object, See QObject::QObject
+ * @param name The name of this object, See TQObject::QObject
* @see BoxContainerItem::readConfig
*/